/*
   Program   :  CopyFile.PRG
   Written by:  Jamal Assaf        Copyright 1992
   Date      :  July 8, 1992

   Description: This function copies one file to another using
                LOW LEVEL I/O functions.
                It is faster than the COPY FILE command in clipper;
                almost twice as fast.

                The larger the buffer size, the better the performance
                because there will less file reads and thus less
                disk activity. That translates into faster copying.
                BUFSIZE should be less 63K, Clipper's string limit.
                I use 40960 which seems to be satisfactory

          Note: The Buffer size should a multiple of 512

*/

#include "fileio.ch"

#define BUFSIZE 40960

FUNCTION CopyFile(cOldFile, cNewFile)
LOCAL nOutHandle,;
      nInHandle := FOPEN(cOldFile,FO_READ), ;
      cBuffer   := SPACE(BUFSIZE), nBytes := 0

    IF nInHandle < 0       //  error opening cOldFile
       ShowMsg("Error " + STR(FERROR(),2,0) + " opening file ";
                + cOldFile, "GR+/R")
    ELSE
      IF ( nOutHandle := FCREATE(cNewFile, FC_NORMAL) ) > -1    // No error
          DO WHILE (nBytes := FREAD(nInHandle, @cBuffer, BUFSIZE)) > 0
             FWRITE(nOutHandle, cBuffer, nBytes)
          ENDDO
          FCLOSE(nInHandle)
          FCLOSE(nOutHandle)
      ELSE
          ShowMsg("Error " + STR(FERROR(),2,0) + " creating file ";
                  + cNewFile, "GR+/R")
      ENDIF
   endif
RETURN NIL

STATIC FUNCTION ShowMsg(cMsg, cColor)
  LOCAL cScrnBuffer := SAVESCREEN( MAXROW(),0,MAXROW(),MAXCOL() )

  @ MAXROW(), 0 SAY cMsg COLOR cColor
  Inkey(0)

  RESTSCREEN( MAXROW(),0,MAXROW(),MAXCOL(), cScrnBuffer )
RETURN NIL
